==> kornia-0.1.4.post2.tar.gz: kornia-0.1.4.post2/kornia/feature/__init__.py <==
from .responses import (CornerHarris,
                        CornerGFTT,
                        BlobHessian,
                        harris_response,
                        gftt_response,
                        hessian_response)
from .nms import NonMaximaSuppression2d, non_maxima_suppression2d
from .laf import (extract_patches_from_pyramid,
                  extract_patches_simple,
                  normalize_laf,
                  denormalize_laf,
                  laf_to_boundary_points,
                  ellipse_to_laf,
                  make_upright,
                  scale_laf,
                  get_laf_scale,
                  raise_error_if_laf_is_not_valid,
                  laf_is_inside_image)
from .siftdesc import SIFTDescriptor
from .scale_space_detector import ScaleSpaceDetector, PassLAF
from .affine_shape import LAFAffineShapeEstimator, PatchAffineShapeEstimator
from .orientation import LAFOrienter, PatchDominantGradientOrientation

__all__ = [
    "non_maxima_suppression2d",
    "harris_response",
    "gftt_response",
    "hessian_response",
    "NonMaximaSuppression2d",
    "CornerHarris",
    "CornerGFTT",
    "BlobHessian",
    "extract_patches_from_pyramid",
    "extract_patches_simple",
    "normalize_laf",
    "denormalize_laf",
    "laf_to_boundary_points",
    "ellipse_to_laf",
    "make_upright",
    "get_laf_scale",
    "scale_laf",
    "SIFTDescriptor",
    "PassLAF",
    "ScaleSpaceDetector",
    "LAFAffineShapeEstimator",
    "PatchAffineShapeEstimator",
    "LAFOrienter",
    "PatchDominantGradientOrientation",
    "raise_error_if_laf_is_not_valid",
    "laf_is_inside_image",
]

==> kornia-0.2.0.tar.gz: kornia-0.2.0/kornia/feature/__init__.py <==
from .responses import (CornerHarris,
                        CornerGFTT,
                        BlobHessian,
                        harris_response,
                        gftt_response,
                        hessian_response)
from .nms import (NonMaximaSuppression2d,
                  nms2d,
                  NonMaximaSuppression3d,
                  nms3d)

# Backward compatibility
from .nms import nms2d as non_maxima_suppression2d
from .nms import nms3d as non_maxima_suppression3d

from .laf import (extract_patches_from_pyramid,
                  extract_patches_simple,
                  normalize_laf,
                  denormalize_laf,
                  laf_to_boundary_points,
                  ellipse_to_laf,
                  make_upright,
                  scale_laf,
                  get_laf_scale,
                  get_laf_center,
                  get_laf_orientation,
                  raise_error_if_laf_is_not_valid,
                  laf_from_center_scale_ori,
                  laf_is_inside_image,
                  laf_to_three_points,
                  laf_from_three_points)
from .siftdesc import SIFTDescriptor
from .scale_space_detector import ScaleSpaceDetector, PassLAF
from .affine_shape import LAFAffineShapeEstimator, PatchAffineShapeEstimator
from .orientation import LAFOrienter, PatchDominantGradientOrientation

__all__ = [
    "nms2d",
    "nms3d",
    "non_maxima_suppression2d",
    "non_maxima_suppression3d",
    "harris_response",
    "gftt_response",
    "hessian_response",
    "NonMaximaSuppression2d",
    "NonMaximaSuppression3d",
    "CornerHarris",
    "CornerGFTT",
    "BlobHessian",
    "extract_patches_from_pyramid",
    "extract_patches_simple",
    "normalize_laf",
    "denormalize_laf",
    "laf_to_boundary_points",
    "ellipse_to_laf",
    "make_upright",
    "get_laf_scale",
    "get_laf_center",
    "get_laf_orientation",
    "scale_laf",
    "SIFTDescriptor",
    "PassLAF",
    "ScaleSpaceDetector",
    "LAFAffineShapeEstimator",
    "PatchAffineShapeEstimator",
    "LAFOrienter",
    "PatchDominantGradientOrientation",
    "raise_error_if_laf_is_not_valid",
    "laf_is_inside_image",
    "laf_from_center_scale_ori",
    "laf_to_three_points",
    "laf_from_three_points",
]
